@@ -3,5 +3,5 @@ import yaml
 
 def get_password():
     variables = yaml.safe_load(open(
-        'inventory/group_vars/gitlab/gitlab.yml'))
+        'playbooks/gitlab/inventory/group_vars/gitlab.yml'))
     return variables['gitlab_password']
