@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'gitlab-host')
-        assert r['attrs']['name'] == 'gitlab-host'
+        assert 'gitlab-host' in self.get_hosts(host='gitlab-host')
 
     def test_service(self, host):
         assert self.is_service_ok('gitlab-host!Gitlab')
