@@ -8,7 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        assert 'gitea-host' in self.get_hosts(host='gitea-host')
+        assert 'forgejo-host' in self.get_hosts(host='forgejo-host')
 
     def test_service(self):
-        assert self.is_service_ok('gitea-host!Hosteadashboard')
+        assert self.is_service_ok('forgejo-host!Hosteadashboard')
