@@ -4,16 +4,27 @@
 
 set -e
 
+function apt_install() {
+    local package="$1"
+    if test "$(dpkg-query -W -f='${db:Status-Abbrev}' $package)" != "ii " ; then
+        $SUDO apt-get -qq update
+        $SUDO apt-get -qq install -y $package
+    fi
+}
+
 function prepare_environment() {
     if test $(id -u) != 0 ; then
         SUDO=sudo
     fi
-    if test "$(dpkg-query -W -f='${db:Status-Abbrev}' git)" != "ii " ; then
-        $SUDO apt-get update
-        $SUDO apt-get install -y git
-    fi
+    apt_install git
     if test -d ~/.ansible && test "$(find ~/.ansible ! -user $(id -u) -print -quit)" ; then
         $SUDO chown -R $(id -u) ~/.ansible
+    else
+	#
+	# If it does not already exist, docker will create it and root will own it
+	# instead of the user.
+	#
+	mkdir -p $HOME/.ansible
     fi
     local d=/var/lib/libvirt/images/enough
     if test -e /usr/sbin/libvirtd && ! test -d $d ; then
@@ -92,7 +103,9 @@ function run_tests() {
 
     find $d \( -name '*.pyc' -o -name '*.pyo' -o -name __pycache__ \) -delete
     if test "$GITLAB_CI" ; then
-        gitlab_container=$(basename $(cat /proc/1/cpuset))  # current container ID
+	apt_install jq ; apt_install curl
+	$SUDO curl --silent --unix-socket /run/docker.sock http:/v1.38/containers/json
+        gitlab_container=$($SUDO curl --silent --unix-socket /var/run/docker.sock http:/v1.38/containers/json | jq --raw-output '. | map(select(.Names[] | contains ("'$HOSTNAME'"))) | .[] | .Id')
         args="--workdir ${CI_PROJECT_DIR} -e CI_PROJECT_DIR=${CI_PROJECT_DIR} --volumes-from ${gitlab_container}"
         : ${PYTEST_ADDOPTS=-m \"not openstack_integration and not libvirt_integration\"}
         PASS_GITLAB_CI="-e GITLAB_CI=${GITLAB_CI}"
